@@ -11,6 +11,7 @@ import numpy as np
 import tensornetwork as tn
 
 from . import gates
+from . import channels
 from .cons import backend, contractor, dtypestr, npdtype
 from .quantum import QuOperator, identity
 from .simplify import _full_light_cone_cancel
@@ -219,6 +220,8 @@ class Circuit(BaseCircuit):
     post_select = mid_measurement
     post_selection = mid_measurement
 
+    # TODO(@refraction-ray): registering kraus channels apart from depolarizing
+
     def depolarizing2(
         self,
         index: int,
@@ -234,10 +237,10 @@ class Circuit(BaseCircuit):
             status < px,
             lambda: gates.x().tensor,  # type: ignore
             lambda: backend.cond(
-                status < px + py,
+                status < px + py,  # type: ignore
                 lambda: gates.y().tensor,  # type: ignore
                 lambda: backend.cond(
-                    status < px + py + pz,
+                    status < px + py + pz,  # type: ignore
                     lambda: gates.z().tensor,  # type: ignore
                     lambda: gates.i().tensor,  # type: ignore
                 ),
@@ -253,6 +256,7 @@ class Circuit(BaseCircuit):
         # roughly benchmark shows that performance of two depolarizing in terms of
         # building time and running time are similar
 
+    # overwritten now, deprecated
     def depolarizing(
         self,
         index: int,
@@ -324,7 +328,7 @@ class Circuit(BaseCircuit):
         # speed is similar to ``unitary_kraus``
         def index2gate2(r: Tensor, kraus: Sequence[Tensor]) -> Tensor:
             # r is int type Tensor of shape []
-            return backend.switch(r, [lambda _=k: _ for k in kraus])
+            return backend.switch(r, [lambda _=k: _ for k in kraus])  # type: ignore
 
         return self._unitary_kraus_template(
             kraus,
@@ -412,6 +416,7 @@ class Circuit(BaseCircuit):
 
         if status is None:
             status = backend.implicit_randu()[0]
+        status = backend.convert_to_tensor(status)
         status = backend.real(status)
         prob_cumsum = backend.cast(prob_cumsum, dtype=status.dtype)  # type: ignore
         r = step_function(status)
@@ -574,6 +579,46 @@ class Circuit(BaseCircuit):
 
     apply_general_kraus = general_kraus
 
+    @staticmethod
+    def apply_general_kraus_delayed(
+        krausf: Callable[..., Sequence[Gate]]
+    ) -> Callable[..., None]:
+        def apply(
+            self: "Circuit",
+            *index: int,
+            status: Optional[float] = None,
+            name: Optional[str] = None,
+            **vars: float,
+        ) -> None:
+            kraus = krausf(**vars)
+            self.apply_general_kraus(kraus, *index, status=status, name=name)
+
+        return apply
+
+    @classmethod
+    def _meta_apply_channels(cls) -> None:
+        for k in channels.channels:
+            setattr(
+                cls,
+                k,
+                cls.apply_general_kraus_delayed(getattr(channels, k + "channel")),
+            )
+            doc = """
+            Apply %s quantum channel on the circuit.
+            See :py:meth:`tensorcircuit.channels.%schannel`
+
+            :param index: Qubit number that the gate applies on.
+            :type index: int.
+            :param status: uniform external random number between 0 and 1
+            :type status: Tensor
+            :param vars: Parameters for the channel.
+            :type vars: float.
+            """ % (
+                k,
+                k,
+            )
+            getattr(cls, k).__doc__ = doc
+
     def is_valid(self) -> bool:
         """
         [WIP], check whether the circuit is legal.
@@ -712,7 +757,7 @@ class Circuit(BaseCircuit):
 
     # TODO(@refraction-ray): more _before function like state_before? and better API?
 
-    def expectation(
+    def expectation(  # type: ignore
         self,
         *ops: Tuple[tn.Node, List[int]],
         reuse: bool = True,
@@ -755,6 +800,7 @@ class Circuit(BaseCircuit):
 
 
 Circuit._meta_apply()
+Circuit._meta_apply_channels()
 
 
 def expectation(
