@@ -14,6 +14,7 @@ from scipy.stats import unitary_group
 
 from .cons import backend, dtypestr, npdtype
 from .backends import get_backend  # type: ignore
+from .utils import arg_alias
 
 thismodule = sys.modules[__name__]
 
@@ -125,6 +126,8 @@ _fredkin_matrix = np.array(
     ]
 )
 
+# TODO(@SUSYUSTC): fix the dtype bug in delayed gates
+
 
 def __rmul__(self: tn.Node, lvalue: Union[float, complex]) -> "Gate":
     newg = Gate(lvalue * self.tensor)
@@ -365,7 +368,7 @@ def meta_gate() -> None:
                 m = np.reshape(m, newshape=(2, 2, 2, 2))
             if m.shape[0] == 8:
                 m = np.reshape(m, newshape=(2, 2, 2, 2, 2, 2))
-            m = m.astype(npdtype)
+            # m = m.astype(npdtype)
             # not enough for new mechanism: register method on class instead of instance
             # temp = partial(gate_wrapper, m, n)
             # temp.__name__ = n
@@ -694,6 +697,7 @@ def any_gate(unitary: Tensor, name: str = "any") -> Gate:
 # any = any_gate
 
 
+@partial(arg_alias, alias_dict={"unitary": ["hermitian", "hamiltonian"]})
 def exponential_gate(unitary: Tensor, theta: float, name: str = "none") -> Gate:
     r"""
     Exponential gate.
@@ -721,7 +725,10 @@ exp_gate = exponential_gate
 # exp = exponential_gate
 
 
-def exponential_gate_unity(unitary: Tensor, theta: float, name: str = "none") -> Gate:
+@partial(arg_alias, alias_dict={"unitary": ["hermitian", "hamiltonian"]})
+def exponential_gate_unity(
+    unitary: Tensor, theta: float, half: bool = False, name: str = "none"
+) -> Gate:
     r"""
     Faster exponential gate directly implemented based on RHS. Only works when :math:`U^2 = I` is an identity matrix.
 
@@ -733,6 +740,9 @@ def exponential_gate_unity(unitary: Tensor, theta: float, name: str = "none") ->
     :type unitary: Tensor
     :param theta: angle in radians
     :type theta: float
+    :param half: if True, the angel theta is mutiplied by 1/2,
+        defaults to False
+    :type half: bool
     :param name: suffix of Gate name
     :type name: str, optional
     :return: Exponential Gate
@@ -745,15 +755,17 @@ def exponential_gate_unity(unitary: Tensor, theta: float, name: str = "none") ->
     i = i.reshape([2 for _ in range(n)])
     unitary = backend.reshape(unitary, [2 for _ in range(n)])
     it = array_to_tensor(i)
+    if half is True:
+        theta = theta / 2.0
     mat = backend.cos(theta) * it - 1.0j * backend.sin(theta) * unitary
     return Gate(mat, name="exp1-" + name)
 
 
 exp1_gate = exponential_gate_unity
 # exp1 = exponential_gate_unity
-rzz_gate = partial(exp1_gate, unitary=_zz_matrix)
-rxx_gate = partial(exp1_gate, unitary=_xx_matrix)
-ryy_gate = partial(exp1_gate, unitary=_yy_matrix)
+rzz_gate = partial(exp1_gate, unitary=_zz_matrix, half=True)
+rxx_gate = partial(exp1_gate, unitary=_xx_matrix, half=True)
+ryy_gate = partial(exp1_gate, unitary=_yy_matrix, half=True)
 
 
 def multicontrol_gate(unitary: Tensor, ctrl: Union[int, Sequence[int]] = 1) -> Operator:
