@@ -16,6 +16,7 @@ from typing import (
     Any,
     Callable,
     Collection,
+    Dict,
     List,
     Optional,
     Sequence,
@@ -35,9 +36,9 @@ try:
 except ImportError:
     pass
 
-from .cons import backend, contractor, dtypestr, npdtype
+from .cons import backend, contractor, dtypestr, npdtype, rdtypestr
 from .backends import get_backend  # type: ignore
-from .utils import is_m1mac
+from .utils import is_m1mac, arg_alias
 
 Tensor = Any
 Graph = Any
@@ -1826,52 +1827,321 @@ def mutual_information(s: Tensor, cut: Union[int, List[int]]) -> Tensor:
     return ha + hb - hab
 
 
+# measurement results and transformations and correlations below
+
+
+def count_s2d(srepr: Tuple[Tensor, Tensor], n: int) -> Tensor:
+    """
+    measurement shots results, sparse tuple representation to dense representation
+    count_vector to count_tuple
+
+    :param srepr: [description]
+    :type srepr: Tuple[Tensor, Tensor]
+    :param n: number of qubits
+    :type n: int
+    :return: [description]
+    :rtype: Tensor
+    """
+    return backend.scatter(
+        backend.cast(backend.zeros([2**n]), srepr[1].dtype),
+        backend.reshape(srepr[0], [-1, 1]),
+        srepr[1],
+    )
+
+
+counts_v2t = count_s2d
+
+
+def count_d2s(drepr: Tensor, eps: float = 1e-7) -> Tuple[Tensor, Tensor]:
+    """
+    measurement shots results, dense representation to sparse tuple representation
+    non-jittable due to the non fixed return shape
+    count_tuple to count_vector
+
+    :Example:
+
+    >>> tc.quantum.counts_d2s(np.array([0.1, 0, -0.3, 0.2]))
+    (array([0, 2, 3]), array([ 0.1, -0.3,  0.2]))
+
+    :param drepr: [description]
+    :type drepr: Tensor
+    :param eps: cutoff to determine nonzero elements, defaults to 1e-7
+    :type eps: float, optional
+    :return: [description]
+    :rtype: Tuple[Tensor, Tensor]
+    """
+    # unjittable since the return shape is not fixed
+    # tf.boolean_mask is better but no jax counterpart
+    xl = []
+    cl = []
+    for i, j in enumerate(drepr):
+        if backend.abs(j) > eps:
+            xl.append(i)
+            cl.append(j)
+    xl = backend.convert_to_tensor(xl)
+    cl = backend.stack(cl)
+    return xl, cl
+
+
+count_t2v = count_d2s
+
+
+def sample_int2bin(sample: Tensor, n: int) -> Tensor:
+    """
+    int sample to bin sample
+
+    :param sample: in shape [trials] of int elements in the range [0, 2**n)
+    :type sample: Tensor
+    :param n: number of qubits
+    :type n: int
+    :return: in shape [trials, n] of element (0, 1)
+    :rtype: Tensor
+    """
+    confg = backend.mod(
+        backend.right_shift(sample[..., None], backend.reverse(backend.arange(n))),
+        2,
+    )
+    return confg
+
+
+def sample_bin2int(sample: Tensor, n: int) -> Tensor:
+    """
+    bin sample to int sample
+
+    :param sample: in shape [trials, n] of elements (0, 1)
+    :type sample: Tensor
+    :param n: number of qubits
+    :type n: int
+    :return: in shape [trials]
+    :rtype: Tensor
+    """
+    power = backend.convert_to_tensor([2**j for j in reversed(range(n))])
+    return backend.sum(sample * power, axis=-1)
+
+
+def sample2count(
+    sample: Tensor, n: int, jittable: bool = True
+) -> Tuple[Tensor, Tensor]:
+    """
+    sample_int to count_tuple
+
+    :param sample: _description_
+    :type sample: Tensor
+    :param n: _description_
+    :type n: int
+    :param jittable: _description_, defaults to True
+    :type jittable: bool, optional
+    :return: _description_
+    :rtype: Tuple[Tensor, Tensor]
+    """
+    d = 2**n
+    if not jittable:
+        results = backend.unique_with_counts(sample)  # non-jittable
+    else:  # jax specified
+        results = backend.unique_with_counts(sample, size=d, fill_value=-1)
+    return results  # type: ignore
+
+
+def count_vector2dict(count: Tensor, n: int, key: str = "bin") -> Dict[Any, int]:
+    """
+    convert_vector to count_dict_bin or count_dict_int
+
+    :param count: tensor in shape [2**n]
+    :type count: Tensor
+    :param n: number of qubits
+    :type n: int
+    :param key: can be "int" or "bin", defaults to "bin"
+    :type key: str, optional
+    :return: _description_
+    :rtype: _type_
+    """
+    d = {i: backend.numpy(count[i]).item() for i in range(2**n)}
+    if key == "int":
+        return d
+    else:
+        dn = {}
+        for k, v in d.items():
+            kn = str(bin(k))[2:].zfill(n)
+            dn[kn] = v
+        return dn
+
+
+def count_tuple2dict(
+    count: Tuple[Tensor, Tensor], n: int, key: str = "bin"
+) -> Dict[Any, int]:
+    """
+    count_tuple to count_dict_bin or count_dict_int
+
+    :param count: count_tuple format
+    :type count: Tuple[Tensor, Tensor]
+    :param n: number of qubits
+    :type n: int
+    :param key: can be "int" or "bin", defaults to "bin"
+    :type key: str, optional
+    :return: count_dict
+    :rtype: _type_
+    """
+    d = {
+        backend.numpy(i).item(): backend.numpy(j).item()
+        for i, j in zip(count[0], count[1])
+        if i >= 0
+    }
+    if key == "int":
+        return d
+    else:
+        dn = {}
+        for k, v in d.items():
+            kn = str(bin(k))[2:].zfill(n)
+            dn[kn] = v
+        return dn
+
+
+@partial(arg_alias, alias_dict={"counts": ["shots"], "format": ["format_"]})
 def measurement_counts(
-    state: Tensor, counts: int = 8192, sparse: bool = True
-) -> Union[Tuple[Tensor, Tensor], Tensor]:
+    state: Tensor,
+    counts: Optional[int] = 8192,
+    format: str = "count_vector",
+    is_prob: bool = False,
+    random_generator: Optional[Any] = None,
+    jittable: bool = False,
+) -> Any:
     """
     Simulate the measuring of each qubit of ``p`` in the computational basis,
     thus producing output like that of ``qiskit``.
 
+    Six formats of measurement counts results:
+
+    "sample_int": # np.array([0, 0])
+
+    "sample_bin": # [np.array([1, 0]), np.array([1, 0])]
+
+    "count_vector": # np.array([2, 0, 0, 0])
+
+    "count_tuple": # (np.array([0]), np.array([2]))
+
+    "count_dict_bin": # {"00": 2, "01": 0, "10": 0, "11": 0}
+
+    "count_dict_int": # {0: 2, 1: 0, 2: 0, 3: 0}
+
     :Example:
 
-    >>> qu.measurement_counts(np.ones([2**6])/2**3, counts=16, sparse=True)
-    (array([ 4,  7, 13, 19, 21, 33, 36, 41, 42, 45, 49, 50, 54, 56]),
-     array([1, 1, 2, 1, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1]))
-    >>> qu.measurement_counts(np.ones([2**6])/2**3, counts=16, sparse=False)
-    array([0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0,
-       0, 0, 2, 0, 0, 0, 0, 2, 0, 0, 1, 0, 1, 2, 0, 0, 0, 0, 0, 0, 0, 1,
-       0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0])
+    >>> n = 4
+    >>> w = tc.backend.ones([2**n])
+    >>> tc.quantum.measurement_results(w, counts=3, format="sample_bin", jittable=True)
+    array([[0, 0, 1, 0],
+        [0, 1, 1, 0],
+        [0, 1, 1, 1]])
+    >>> tc.quantum.measurement_results(w, counts=3, format="sample_int", jittable=True)
+    array([ 7, 15, 11])
+    >>> tc.quantum.measurement_results(w, counts=3, format="count_vector", jittable=True)
+    array([0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 0, 1])
+    >>> tc.quantum.measurement_results(w, counts=3, format="count_tuple")
+    (array([1, 2, 8]), array([1, 1, 1]))
+    >>> tc.quantum.measurement_results(w, counts=3, format="count_dict_bin")
+    {'0001': 1, '0011': 1, '1101': 1}
+    >>> tc.quantum.measurement_results(w, counts=3, format="count_dict_int")
+    {3: 1, 6: 2}
 
     :param state: The quantum state, assumed to be normalized, as either a ket or density operator.
     :type state: Tensor
     :param counts: The number of counts to perform.
     :type counts: int
-    :param sparse: Defaults True. The bool indicating whether
-        the return form is in the form of two array or one of the same length as the ``state`` (if ``sparse=False``).
-    :type sparse: bool
+    :param format: defaults to be "direct", see supported format above
+    :type format: str
+    :param is_prob: if True, the `state` is directly regarded as a probability list,
+        defaults to be False
+    :type is_prob: bool
+    :param random_generator: random_generator, defaults to None
+    :type random_general: Optional[Any]
+    :param jittable: if True, jax backend try using a jittable count, defaults to False
+    :type jittable: bool
     :return: The counts for each bit string measured.
     :rtype: Tuple[]
     """
-    if len(state.shape) == 2:
-        state /= backend.trace(state)
-        pi = backend.real(backend.diagonal(state))
+    if is_prob:
+        pi = state / backend.sum(state)
     else:
-        state /= backend.norm(state)
-        pi = backend.real(backend.conj(state) * state)
-    pi = backend.reshape(pi, [-1])
-    d = int(pi.shape[0])
-    # raw counts in terms of integers
-    raw_counts = backend.implicit_randc(d, shape=counts, p=pi)
-    results = backend.unique_with_counts(raw_counts)
-    if sparse:
-        return results  # type: ignore
-    dense_results = backend.scatter(
-        backend.cast(backend.zeros([d]), results[1].dtype),
-        backend.reshape(results[0], [-1, 1]),
-        results[1],
-    )
-    return dense_results
+        if len(state.shape) == 2:
+            state /= backend.trace(state)
+            pi = backend.abs(backend.diagonal(state))
+        else:
+            state /= backend.norm(state)
+            pi = backend.real(backend.conj(state) * state)
+        pi = backend.reshape(pi, [-1])
+    d = int(backend.shape_tuple(pi)[0])
+    n = int(np.log(d) / np.log(2) + 1e-8)
+    drange = backend.arange(d)
+    if (counts is None) or counts <= 0:
+        if format == "count_vector":
+            return pi
+        elif format == "count_tuple":
+            return count_d2s(pi)
+        elif format == "count_dict_bin":
+            return count_vector2dict(pi, n, key="bin")
+        elif format == "count_dict_int":
+            return count_vector2dict(pi, n, key="int")
+        else:
+            raise ValueError(
+                "unsupported format %s for analytical measurement" % format
+            )
+    else:
+        if random_generator is None:
+            raw_counts = backend.implicit_randc(drange, shape=counts, p=pi)
+        else:
+            raw_counts = backend.stateful_randc(
+                random_generator, a=drange, shape=counts, p=pi
+            )
+        return sample2all(raw_counts, n, format=format, jittable=jittable)
+
+
+measurement_results = measurement_counts
+
+
+@partial(arg_alias, alias_dict={"format": ["format_"]})
+def sample2all(
+    sample: Tensor, n: int, format: str = "count_vector", jittable: bool = False
+) -> Any:
+    """
+    transform ``sample_int`` or ``sample_bin`` form results to other forms specified by ``format``
+
+    :param sample: measurement shots results in ``sample_int`` or ``sample_bin`` format
+    :type sample: Tensor
+    :param n: number of qubits
+    :type n: int
+    :param format: see the doc in the doc in :py:meth:`tensorcircuit.quantum.measurement_results`,
+        defaults to "count_vector"
+    :type format: str, optional
+    :param jittable: only applicable to count transformation in jax backend, defaults to False
+    :type jittable: bool, optional
+    :return: measurement results specified as ``format``
+    :rtype: Any
+    """
+    if len(backend.shape_tuple(sample)) == 1:
+        sample_int = sample
+        sample_bin = sample_int2bin(sample, n)
+    elif len(backend.shape_tuple(sample)) == 2:
+        sample_int = sample_bin2int(sample, n)
+        sample_bin = sample
+    else:
+        raise ValueError("unrecognized tensor shape for sample")
+    if format == "sample_int":
+        return sample_int
+    elif format == "sample_bin":
+        return sample_bin
+    else:
+        count_tuple = sample2count(sample_int, n, jittable)
+        if format == "count_tuple":
+            return count_tuple
+        elif format == "count_vector":
+            return count_s2d(count_tuple, n)
+        elif format == "count_dict_bin":
+            return count_tuple2dict(count_tuple, n, key="bin")
+        elif format == "count_dict_int":
+            return count_tuple2dict(count_tuple, n, key="int")
+        else:
+            raise ValueError(
+                "unsupported format %s for finite shots measurement" % format
+            )
 
 
 def spin_by_basis(n: int, m: int, elements: Tuple[int, int] = (1, -1)) -> Tensor:
@@ -1903,10 +2173,34 @@ def spin_by_basis(n: int, m: int, elements: Tuple[int, int] = (1, -1)) -> Tensor
     return backend.reshape(s, [-1])
 
 
+def correlation_from_samples(index: Sequence[int], results: Tensor, n: int) -> Tensor:
+    """
+    Compute :math:`\prod_{i\in \\text{index}} s_i (s=\pm 1)`,
+    Results is in the format of "sample_int" or "sample_bin"
+
+    :param index: list of int, indicating the position in the bitstring
+    :type index: Sequence[int]
+    :param results: sample tensor
+    :type results: Tensor
+    :param n: number of qubits
+    :type n: int
+    :return: Correlation expectation from measurement shots
+    :rtype: Tensor
+    """
+    if len(backend.shape_tuple(results)) == 1:
+        results = sample_int2bin(results, n)
+    results = results * 2 - 1
+    r = results[:, index[0]]
+    for i in index[1:]:
+        r *= results[:, i]
+    return backend.mean(r)
+
+
 def correlation_from_counts(index: Sequence[int], results: Tensor) -> Tensor:
     """
     Compute :math:`\prod_{i\in \\text{index}} s_i`,
     where the probability for each bitstring is given as a vector ``results``.
+    Results is in the format of "count_vector"
 
     :Example:
 
@@ -1924,6 +2218,8 @@ def correlation_from_counts(index: Sequence[int], results: Tensor) -> Tensor:
     :rtype: Tensor
     """
     results = backend.reshape(results, [-1])
+    results = backend.cast(results, rdtypestr)
+    results /= backend.sum(results)
     n = int(np.log(results.shape[0]) / np.log(2))
     for i in index:
         results = results * backend.cast(spin_by_basis(n, i), results.dtype)
