@@ -93,7 +93,7 @@ def test_jittable_measure(backend):
             c.H(i)
         for j in range(nlayers):
             for i in range(n - 1):
-                c.exp1(i, i + 1, theta=param[2 * j, i], unitary=tc.gates._zz_matrix)
+                c.exp1(i, i + 1, theta=param[2 * j, i], hamiltonian=tc.gates._zz_matrix)
             for i in range(n):
                 c.rx(i, theta=param[2 * j + 1, i])
         return c.measure_jit(0, 1, 2, with_prob=True)
@@ -586,7 +586,7 @@ def test_circuit_split(backend):
             c.H(i)
         for j in range(2):
             for i in range(n - 1):
-                c.exp1(i, i + 1, theta=param[2 * j, i], unitary=tc.gates._zz_matrix)
+                c.exp1(i, i + 1, theta=param[2 * j, i], hermitian=tc.gates._zz_matrix)
             for i in range(n):
                 c.rx(i, theta=param[2 * j + 1, i])
         loss = c.expectation(
@@ -1002,10 +1002,14 @@ def test_batch_sample(backend):
     c.cnot(0, 1)
     print(c.sample())
     print(c.sample(batch=8))
-    print(c.sample(status=tc.backend.get_random_state(42)))
+    print(c.sample(random_generator=tc.backend.get_random_state(42)))
     print(c.sample(allow_state=True))
     print(c.sample(batch=8, allow_state=True))
-    print(c.sample(batch=8, allow_state=True, status=tc.backend.get_random_state(42)))
+    print(
+        c.sample(
+            batch=8, allow_state=True, random_generator=tc.backend.get_random_state(42)
+        )
+    )
 
 
 def test_expectation_y_bug():
@@ -1092,3 +1096,68 @@ def test_minus_index():
     np.testing.assert_allclose(tc.backend.real(c.expectation_ps(x=[1])), 1, atol=1e-5)
     np.testing.assert_allclose(tc.backend.real(c.expectation_ps(x=[-1])), 0, atol=1e-5)
     np.testing.assert_allclose(tc.backend.real(c.expectation_ps(z=[-2])), 0, atol=1e-5)
+
+
+@pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb")])
+def test_sexpps(backend):
+    c = tc.Circuit(1, inputs=1 / np.sqrt(2) * np.array([1.0, 1.0j]))
+    y = c.sample_expectation_ps(y=[0])
+    ye = c.expectation_ps(y=[0])
+    np.testing.assert_allclose(y, 1.0, atol=1e-5)
+    np.testing.assert_allclose(ye, 1.0, atol=1e-5)
+
+    c = tc.Circuit(4)
+    c.H(0)
+    c.cnot(0, 1)
+    c.rx(1, theta=0.3)
+    c.rz(2, theta=-1.2)
+    c.ccnot(2, 3, 1)
+    c.rzz(0, 3, theta=0.5)
+    c.ry(3, theta=2.2)
+    c.s(1)
+    c.td(2)
+    y = c.sample_expectation_ps(x=[1], y=[0], z=[2, 3])
+    ye = c.expectation_ps(x=[1], y=[0], z=[2, 3])
+    np.testing.assert_allclose(ye, y, atol=1e-5)
+    y2 = c.sample_expectation_ps(x=[1], y=[0], z=[2, 3], shots=81920)
+    assert np.abs(y2 - y) < 0.01
+
+
+@pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb")])
+def test_sample_format(backend):
+    c = tc.Circuit(2)
+    c.H(0)
+    c.cnot(0, 1)
+    key = tc.backend.get_random_state(42)
+    for allow_state in [False, True]:
+        print("allow_state: ", allow_state)
+        for batch in [None, 1, 3]:
+            print("  batch: ", batch)
+            for format_ in [
+                None,
+                "sample_int",
+                "sample_bin",
+                "count_vector",
+                "count_tuple",
+                "count_dict_bin",
+                "count_dict_int",
+            ]:
+                print("    format: ", format_)
+                print(
+                    "      ",
+                    c.sample(
+                        batch=batch,
+                        allow_state=allow_state,
+                        format_=format_,
+                        random_generator=key,
+                    ),
+                )
+
+
+@pytest.mark.parametrize("backend", [lf("npb"), lf("tfb"), lf("jaxb")])
+def test_channel_auto_register(backend, highp):
+    c = tc.Circuit(2)
+    c.H(0)
+    c.reset(0, status=0.8)
+    s = c.state()
+    np.testing.assert_allclose(s[0], 1.0, atol=1e-9)
